#include <stdio.h>
#include <proto/dos.h>
#include <proto/exec.h>
#include <proto/capsimage.h>

#define TEMPLATE "FILE/A"

#define ARG_FILE 0
#define ARG_NUM  1

LONG args[ARG_NUM];

struct RDArgs *rdargs;
struct MsgPort *msgport;
struct IORequest *ioreq;
struct DosLibrary *DOSBase;
struct Library *CapsImageBase;

int PrintImageInfo(STRPTR name)
{
	int i, rc = RETURN_ERROR;

	LONG id = CAPSAddImage();

	if (CAPSLockImage(id, name) == imgeOk)
	{
		struct CapsImageInfo cii;

		if (CAPSGetImageInfo(&cii, id) == imgeOk)
		{
			printf("Type: %ld\n", cii.type);
			printf("Release: %ld\n", cii.release);
			printf("Revision: %ld\n", cii.revision);
			printf("Min Cylinder: %ld\n", cii.mincylinder);
			printf("Max Cylinder: %ld\n", cii.maxcylinder);
			printf("Min Head: %ld\n", cii.minhead);
			printf("Max Head: %ld\n", cii.maxhead);
			printf("Creation Date: %04ld/%02ld/%02ld %02ld:%02ld:%02ld.%03ld\n", cii.crdt.year, cii.crdt.month, cii.crdt.day, cii.crdt.hour, cii.crdt.min, cii.crdt.sec, cii.crdt.tick);
			printf("Platforms:");
			for (i = 0; i < CAPS_MAXPLATFORM; i++)
				if (cii.platform[i] != ciipNA)
					printf(" %s", CAPSGetPlatformName(cii.platform[i]));
			printf("\n");

			rc = RETURN_OK;
		}
		CAPSUnlockImage(id);
	}
	CAPSRemImage(id);
	
	return rc;
}

int main(void)
{
	int rc = RETURN_FAIL;

	if ((DOSBase = (struct DosLibrary *)OpenLibrary(DOSNAME, 36)))
	{
		if ((msgport = CreateMsgPort()))
		{
			if ((ioreq = CreateIORequest(msgport, sizeof(struct IORequest))))
			{
				if (!OpenDevice(CAPS_NAME, 0, ioreq, 0))
				{
					CapsImageBase = (struct Library *)ioreq->io_Device;

					if ((rdargs = ReadArgs(TEMPLATE, args, NULL)))
					{
						if (CAPSInit() == imgeOk)
						{
							rc = PrintImageInfo((STRPTR)args[ARG_FILE]);
							CAPSExit();
						}
						FreeArgs(rdargs);
					}
					else
						PrintFault(IoErr(), NULL);
					CloseDevice(ioreq);
				}
				DeleteIORequest(ioreq);
			}
			DeleteMsgPort(msgport);
		}
		CloseLibrary((struct Library *)DOSBase);
	}
	return rc;
}

